@@ -1,12 +1,9 @@
 import gc
 import weakref
 
-import pytest
-
 import aio_pika
 
 
-@pytest.mark.skip(reason="temporary skipped")
 async def test_leak_unclosed_channel(create_connection):
     rabbitmq_connection = await create_connection()
 
@@ -24,7 +21,6 @@ async def test_leak_unclosed_channel(create_connection):
     assert len(tuple(weakset)) == 0
 
 
-@pytest.mark.skip(reason="temporary skipped")
 async def test_leak_closed_channel(create_connection):
     rabbitmq_connection = await create_connection()
 
